#include "StdAfx.h"
#include "Tutorial3D.h"

using namespace std;

CTutorial3D::CTutorial3D(void)
{
	m_pPixelShaderPhong = m_pVertexShaderPhong = NULL;
	m_pTexDiffuse = NULL;
}

CTutorial3D::~CTutorial3D(void)
{
}

bool CTutorial3D::Init()
{
	RECT rc;

	GetClientRect(GetHwnd(), &rc);
	int iWndWidth = rc.right-rc.left;
	int iWndHeight = rc.bottom-rc.top;

	//  
	if (!Graphics::get().Init(GetHwnd(), iWndWidth, iWndHeight))
		return FALSE;

	//   
	m_pVertexShaderPhong = Graphics::get().LoadShader("vs-phong.hlsl", "main", "vs_2_0");

	//   
	m_pPixelShaderPhong  = Graphics::get().LoadShader("ps-phong.hlsl", "pixel_shader_main", "ps_2_0");

	m_pMesh = Graphics::get().LoadMesh("Data/1.gamemodel");
	m_pTexDiffuse = Graphics::get().LoadTexture(L"Data/texture-diffuse.dds");

	return TRUE;
}

void CTutorial3D::CleanUp()
{
	Graphics::get().Cleanup();
}

void CTutorial3D::Render()
{
	Graphics& gr = Graphics::get();
	if (!FAILED(gr.StartRender(0x00000000)))
	{
		//  -
		gr.SetRenderState(D3DRS_CULLMODE, D3DCULL_NONE);
		gr.SetRenderState(D3DRS_LIGHTING, FALSE);
		gr.SetRenderState(D3DRS_FILLMODE, D3DFILL_SOLID);
		gr.SetRenderState(D3DRS_SHADEMODE, D3DSHADE_GOURAUD);
		gr.SetRenderState(D3DRS_ZENABLE, D3DZB_TRUE);
		gr.SetRenderState(D3DRS_ZFUNC, D3DCMP_LESSEQUAL);
		gr.SetRenderState(D3DRS_ZWRITEENABLE, TRUE);

		D3DXMATRIX mat, matViewProj, matProj, matView;
		D3DXMatrixIdentity(&mat);

		RECT rc;
		GetClientRect(GetHwnd(), &rc);
		int iWndWidth = rc.right-rc.left;
		int iWndHeight = rc.bottom-rc.top;

		//    
		D3DXMatrixTranslation(&matView, 0, 0, 0);
		D3DXMatrixOrthoLH(&matProj, iWndWidth, -iWndHeight, -300, 300);

		//   /
		D3DXMatrixMultiply(&matViewProj, &matView, &matProj);

		//   3-   
		gr.SetRenderState( D3DRS_ALPHABLENDENABLE, FALSE);
		static float a=0;
		a+=.01f;
		D3DXMatrixRotationY(&mat, a);

		//  
		gr.SetPixelShader(m_pPixelShaderPhong);
		gr.SetVertexShader(m_pVertexShaderPhong);
		//    
		m_pVertexShaderPhong->SetMatrix("mWorld", &mat);
		m_pVertexShaderPhong->SetMatrix("mViewProjection", &matViewProj);
		m_pVertexShaderPhong->SetVector("vLight", &D3DXVECTOR4(-250, 0, -0, 0));
		m_pVertexShaderPhong->SetVector("vCam", &D3DXVECTOR4(0, 0, -250, 0));

		gr.SetTexture(0, m_pTexDiffuse);
		gr.Draw(m_pMesh);
		//   3-

		//  
		gr.EndRender();
	}
}

void CTutorial3D::UpdateFrame()
{
	ProcessUserInput(.02f);
	UpdateWorld(.02f);
}

void CTutorial3D::ProcessUserInput(float fDeltaTime)
{
/*
	int dx=0;
	if (GetAsyncKeyState(m_keyLeft)&32768)
		dx--; //  
	if (GetAsyncKeyState(m_keyRight)&32768)
		dx++; //  
*/
}

void CTutorial3D::UpdateWorld(const float fDeltaTime)
{
}
